@@ -3,4 +3,4 @@ from django.apps import AppConfig
 
 class MinimaluserConfig(AppConfig):
     default_auto_field = "django.db.models.BigAutoField"
-    name = "minimaluser"
+    name = "django_seriously.minimaluser"
